@@ -49,7 +49,7 @@ public:
   {
     for (size_t i=0; i<=9; i++) {
       models[i]=new Lum::Model::Action();
-      AttachModel(models[i]);
+      Observe(models[i]);
     }
   }
 
@@ -133,7 +133,7 @@ public:
   {
     for (size_t i=0; i<=8; i++) {
       models[i]=new Lum::Model::Boolean(value & (1 << i));
-      AttachModel(models[i]);
+      Observe(models[i]);
     }
   }
 
