@@ -23,7 +23,6 @@
 
 #include <Lum/Model/DataStream.h>
 
-#include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Dialog.h>
 #include <Lum/Grid.h>
@@ -31,7 +30,6 @@
 #include <Lum/PercentBar.h>
 #include <Lum/Space.h>
 #include <Lum/Text.h>
-#include <Lum/WindowGroup.h>
 
 static Lum::Object* GetPercentBar(size_t count)
 {
@@ -75,13 +73,9 @@ StatisticsDialog::~StatisticsDialog()
 
 void StatisticsDialog::PreInit()
 {
-  Lum::Button      *button;
   Lum::ButtonRow   *row;
   Lum::Grid        *grid;
   Lum::Panel       *vert;
-  Lum::WindowGroup *wGroup;
-
-  wGroup=new Lum::WindowGroup();
 
   vert=new Lum::VPanel();
 
@@ -121,21 +115,11 @@ void StatisticsDialog::PreInit()
 
   vert->Add(new Lum::VSpace());
 
-  row=new Lum::ButtonRow();
+  row=Lum::ButtonRow::CreateClose(GetClosedAction());
   row->SetFlex(true,false);
-
-  button=new Lum::Button();
-  button->SetFlex(true,true);
-  button->SetText(_ld(dlgButtonOk));
-  button->SetType(Lum::Button::typeDefault);
-  button->SetModel(GetClosedAction());
-  row->Add(button);
-
   vert->Add(row);
 
-  wGroup->SetMain(vert);
-
-  SetTop(wGroup);
+  SetMain(vert);
 
   Dialog::PreInit();
 }
